@@ -1,6 +1,4 @@
-use funes;
-
 #[actix_web::main]
 async fn main() -> std::io::Result<()> {
-    Ok(funes::server::new().await?)
+    funes::server::new().await
 }
